/**
 * 桥操作
 */
interface BridgeOperation {
    req: Function;
    def: Function;
}
/**
 * 桥返回结果
 */
interface BridgeRequestResult {
    err: String;
    result: Object;
}
interface ViewImage {
    image: String;
    title: String;
}
interface ResultObject {
    err: String;
    result: any;
}
interface VideoInfo {
    video: String;
}
interface ChooseResourceResult {
    err: String;
    result: String;
}
interface DialogInput {
    buttons: String[];
}
interface ToastInput {
    title: String;
    duration: Number;
}
interface WebAppInput {
    url: String;
    title: String;
    disableHeader: Boolean;
    enableBridge: Boolean;
    beforeLoad: Object;
}
interface RouterInput {
    router: String;
    params: Object;
}
interface FetchInput {
    url: String;
    option: Object;
}
interface RequestFullscreenVideoPlayInput {
    start: Boolean;
}
interface AudioRecordInput {
    start: Boolean;
}
interface ShareInput {
    share: Object;
    id: any;
}
interface LinkInput {
    url: String;
}
interface PickerMenuItem extends Object {
    title: String;
}
interface PickerMenuInput {
    items: Array<PickerMenuItem>;
}
interface LaunchWechatProgramInput {
    userName: String;
    path: String;
    extDic: Object;
}
interface CurrentPositionInput {
    type: String;
}
interface RequestInput {
    url: String;
    option: Object;
}
interface RegisterAppEventInput {
    event: String;
}
interface UnRegisterAppEventInput {
    event: String;
}
interface TriggerAppEventInput {
    event: String;
    params: any;
}
declare enum Orientation {
    "PORTRAIT" = 0,
    "LANDSCAPE" = 1,
    "LANDSCAPE-RIGHT" = 2,
    "UNLOCK" = 3
}
interface OrientationControlInput {
    orientation: Orientation;
}
interface DlnaControlInput {
    media: String;
}
interface MusicControlItem {
    title: String;
    artwork: String;
    artist: String;
    album: String;
}
declare enum MusicControlState {
    "play",
    "pause"
}
interface MusicControlInput {
    stop?: Boolean;
    item?: MusicControlItem;
    state?: MusicControlState;
}
interface ReadFileInput {
    path: string;
    encoding: string;
}
interface SaveFileInput {
    path: string;
    body: string;
    encoding: string;
}
interface UnZipFileInput {
    path: string;
    pass: string;
    encoding: string;
}
interface UnZipStreamInput {
    body: string;
    pass: string;
    encoding: string;
}
interface Hook {
    keys: string[] | string;
    before?(api: string, input: any, originInput?: any): any;
    after?(api: string, response: any, originResponse?: any): any;
}
interface WebBridgeApiCls {
    /**
     * 版本
     */
    version: string;
    /**
     * 请求自定义接口
     */
    requestApi(api: string, params: any): Promise<any>;
    /**
     * 定义本地接口
     */
    defineApi(api: string, handle: Function, times?: number): void;
    /**
     * ping
     */
    ping(input: any): Promise<any>;
    /**
     * 请求
     */
    requireVersion(input: Object): Promise<any>;
    /**
     * 系统信息
     */
    sysinfo(): Promise<any>;
    /**
     * 扫描二维码
     * @param {*} input
     */
    scanCode(input: Object): Promise<any>;
    /**
     * 请求授权
     */
    authorize(input: Object): Promise<any>;
    /**
     * 获取当前登录用户信息
     */
    getUserInfo(input: Object): Promise<any>;
    /**
     * 网络请求(Deprecated)
     * @param {*} input
     */
    fetch(input: FetchInput): Promise<any>;
    /**
     * 网络请求
     * @param {*} input
     */
    request(input: RequestInput): Promise<any>;
    /**
     * 打开路由
     * @param {*} RouterInput
     */
    router(input: RouterInput): Promise<any>;
    /**
     * 打开支持桥的web页面
     * @param {} WebAppInput
     */
    showWebApp(input: WebAppInput): Promise<any>;
    /**
     * toast
     * @param {*} ToastInput
     */
    showToast(input: ToastInput): Promise<any>;
    /**
     * 弹出对话框
     * @param {*} DialogInput
     * @type {Number}
     */
    showDialog(input: DialogInput): Promise<any>;
    /**
     * 选择图片
     * @param input
     * @type {Promise<ResultObject>}
     */
    chooseImage(input: Object): Promise<any>;
    /**
     * 选择视频
     * @param input
     * @type {Promise<ResultObject>}
     */
    chooseVideo(input: Object): Promise<any>;
    /**
     * 预览大图
     * @param input ViewImage[]
     * @type {Promise<ResultObject>}
     */
    showImageViewer(input: ViewImage[]): Promise<any>;
    /**
     * 播放全屏视频
     * @param input
     */
    showFullVideoPlayer(input: VideoInfo): Promise<any>;
    /**
     * 请求全屏 注：此接口是webview界面特有接口
     * @param input
     */
    requestFullscreenVideoPlay(input: RequestFullscreenVideoPlayInput): Promise<any>;
    /**
     * 请求权限
     * @param input
     */
    checkPermission(input: any): Promise<any>;
    /**
     * 录制麦克风声音
     * @param input
     */
    audioRecord(input: AudioRecordInput): Promise<any>;
    /**
     * 分享
     * @param input
     */
    share(input: ShareInput): Promise<any>;
    /**
     * 分享
     * @param input
     */
    openLink(input: LinkInput): Promise<any>;
    /**
     * 显示Picker菜单
     * @param input
     */
    showPickerMenu(input: PickerMenuInput): Promise<any>;
    /**
     * 启动微信小程序
     * @param input
     */
    launchWechatProgram(input: LaunchWechatProgramInput): Promise<any>;
    /**
     * 获取定位信息
     * @param input
     */
    getCurrentPosition(input: CurrentPositionInput): Promise<any>;
    /**
     * 注册全局事件
     * @param input
     * @param callback
     */
    registerAppEvent(input: RegisterAppEventInput, listener: Function): Promise<any>;
    /**
     * 注销全局事件
     * @param input
     */
    unRegisterAppEvent(input: UnRegisterAppEventInput): Promise<any>;
    /**
     * 触发全局事件
     * @param input
     */
    triggerAppEvent(input: TriggerAppEventInput): Promise<any>;
    /**
     * 旋转屏幕
     * @param input
     */
    orientation(input: OrientationControlInput): Promise<any>;
    /**
     * 旋转屏幕
     * @param input
     */
    connectDlna(input: DlnaControlInput): Promise<any>;
    /**
     * 锁屏声音控制
     * @param input
     */
    musicControl(input: MusicControlInput): Promise<any>;
    /**
     * 读文件
     * @param input
     */
    readFile(input: ReadFileInput): Promise<any>;
    /**
     * 写文件
     * @param input
     */
    saveFile(input: SaveFileInput): Promise<any>;
    /**
     * 解压
     * @param input
     */
    unzip(input: UnZipFileInput | UnZipStreamInput): Promise<any>;
}
